#!/usr/bin/perl
#=======================================================================
# FileName : AileHttpCtrlCom.pl
# Summary  : HttpコマンドコントローラーAPI
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/03/06 Kiyoshi Oishi      Initial Release
#=======================================================================
use strict;
use CGI;
use JSON;
use Data::Dumper;

use lib '../com-lib';
use ComConst;
use ComFunc;
use ComLog;
use ComKeyConf;

my $rc = ComConst::STS_OK;

$rc = &main();

exit $rc;

#=======================================================================
# FuncName : main
# Summary  : Httpコマンドコントローラー
# Argument : (IN)  $reqFile  : リクエストファイル名(scalar)
#          : (IN)  $resFile  : レスポンスファイル名(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/03/06 Kiyoshi Oishi      Initial Release
#=======================================================================
sub main {
    my $rc = ComConst::STS_OK;
    my %conf = ();
    my %messages = ();
    my $cgi = new CGI;
    my %request = ();
    my %res_data  = (ComConst::JSON_KEY_STS=>ComConst::STS_OK, ComConst::JSON_KEY_MSG=>"");
    my $resData   = "";
    my $header    = "";
    my $postData  = "";
    my $basicAuth = "";
    my $type      = "";
    my $sendkey   = "";
    my $value     = "";
    my $required_request_param = undef;
    my $definedValueVar = "";
    my $data_value      = "";


    # 初期化処理
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::initializeApi($0, \%conf, \%messages);
    }

    # 開始ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D001});

    # リクエストデータの取得
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::getCtrlAipRequestData(\$cgi, \%request);
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # リクエストパラメータチェック
    if($rc == ComConst::STS_OK){
        $type    = defined($request{type}) ? $request{type} : "";
        $sendkey = defined($request{sendkey}) ? ucfirst(lc($request{sendkey})) : "";
        $required_request_param = $ComConst::RequiredRequestParams->{$type}->{$sendkey};

        if(defined($required_request_param)){
            # 必須パラメータが全てあるかチェック
            for my $key (@{$required_request_param->{required}}){
                if(!defined($request{$key}) || $request{$key} eq ""){
                    $rc = ComConst::STS_NG;
                    last;
                }
            }
            if($rc == ComConst::STS_OK){
                # 必須パラメータが全てある場合は、使用する値を取得
                my $valueKey = $required_request_param->{value_param_key};
                my $format = $required_request_param->{format};
                if($format ne ""){
                    $value = sprintf($format, $request{$valueKey});
                }else{
                    $value = $request{$valueKey};
                }
                $data_value = $value;
            }
        }else{
            $rc = ComConst::STS_NG;
        }
        if($rc != ComConst::STS_OK){
            setResponseData(\%res_data, $rc, $messages{CM004E001});
        }
    }

    # リクエストデータチェック
    if($rc == ComConst::STS_OK){
        my $validate_func = $required_request_param->{validate_data_func};
        # データチェック関数が定義されている場合データ内容をチェック
        if($validate_func ne "") {
            if(defined(&$validate_func)){
                my $func = \&$validate_func;
                my $definedNameKey = $required_request_param->{defineValueKeyName};
                if($definedNameKey ne ""){
                    $definedValueVar = $ComKeyConf::AileWebCmdComKey->{$definedNameKey};
                    $rc = $func->($value, $definedValueVar);
                    if($rc == ComConst::STS_OK){
                        $data_value = $definedValueVar->{$value};
                    }
                }else{
                    $rc = $func->($value, undef);
                }
            }else{
                $rc = ComConst::STS_NG;
            }
        }

        if($rc != ComConst::STS_OK){
            setResponseData(\%res_data, $rc, $messages{CM004E001});
        }
    }

    # Basic認証データ取得
    if($rc == ComConst::STS_OK){
        my @httpAuth = split(/ /, $ENV{HTTP_AUTHORIZATION});
        $basicAuth = $httpAuth[1];
    }

    # リクエストデータ作成
    if($rc == ComConst::STS_OK){
        if($type eq ComConst::TYPEKEYSYS){
            $rc = ComFunc::getPostSendData(\$postData, $required_request_param->{template}, $sendkey, $data_value, "");
        }
        elsif($type eq ComConst::TYPEKEYINQ){
            $rc = ComFunc::getPostSendData(\$postData, $required_request_param->{template}, $sendkey, $data_value, $basicAuth);
        }
    }

    # 実行コマンド作成
    if($rc == ComConst::STS_OK){
        if($type eq ComConst::TYPEKEYSYS){
            $rc = setProxyRequestSetting("ExecSystemOperate", \%conf);
        }elsif($type eq ComConst::TYPEKEYINQ){
            $rc = setProxyRequestSetting("InterProcessCom", \%conf);
        }
    }

    # リクエストデータをファイルに出力
    if($rc == ComConst::STS_OK){
        $rc = ComFunc::writeRequestFile($conf{JSON_FILE}->{PROXY_REQUEST}, {data=>$postData});
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # コマンドを呼び出し
    if($rc == ComConst::STS_OK){
        $rc = `$conf{PROXY_EXEC_CMD} $conf{JSON_FILE}->{PROXY_REQUEST} $conf{JSON_FILE}->{PROXY_RESPONSE}`;
        if($rc != ComConst::STS_OK){
            $res_data{ComConst::JSON_KEY_STS} = ComConst::STS_NG;
        }
    }

    # 結果ファイルを読み込む
    $resData = ComFunc::readResponseFile($conf{JSON_FILE}->{PROXY_RESPONSE}, \%res_data);
    ComLog::log_output(ComLog::LOG_DEBUG, Dumper($resData));

    # リクエストファイルとレスポンスファイルを削除
    ComFunc::rmJsonFile($conf{JSON_FILE});

    # 結果を返す
    $header = $cgi->header(-type=>'text/plain', -charset=>'UTF-8');
    ComFunc::setCtrlApiResponsData($resData, $header);

    # 終了ログ出力
    ComLog::log_output(ComLog::LOG_DEBUG, $messages{CM000D002});

    return $rc;
}

#=======================================================================
# FuncName : isNumValidValue
# Summary  : 数値チェック
# Argument : (IN) $value    : チェックデータ(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/11/26 Kiyoshi Oishi      Initial Release
#=======================================================================
sub isNumValidValue {
    my $rc = ComConst::STS_OK;
    my $value = $_[0];
    my $exec_cmd = sprintf(ComConst::GET_AILEUN_PRDCTNO_CMD, ComConst::AILEUN_PRDCTNO_FILE);
    my $prdctNo = "";

    chomp($prdctNo = `$exec_cmd`);
    my $cameraNum = $prdctNo;
    $cameraNum =~ s/YS30(\d{2})-.*/$1/;

    if($value eq "" || $value < 0 || $value > $cameraNum){
         $rc = ComConst::STS_NG;
    }

    return $rc;
}

#=======================================================================
# FuncName : isDefinedValue
# Summary  : 定義済み値チェック
# Argument : (IN) $value    : チェックデータ(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/12/02 Kiyoshi Oishi      Initial Release
#=======================================================================
sub isDefinedValue {
    my $rc = 0;
    my $value = $_[0];
    my $permitValue = $_[1];

    if($permitValue->{$value} eq ""){
        $rc = -1;
    }

    return $rc
}

#=======================================================================
# FuncName : setProxyRequestSetting
# Summary  : 数値チェック
# Argument : (IN) $value    : チェックデータ(scalar)
# Return   : 正常:0, 異常:-1
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/11/26 Kiyoshi Oishi      Initial Release
#=======================================================================
sub setProxyRequestSetting {
    my $rc = ComConst::STS_OK;
    my $baseName = $_[0];
    my $ref_conf = $_[1];

    $$ref_conf{PROXY_EXEC_CMD} = sprintf(ComConst::BASE_CMD_PATH . "/cmd_%s.sh", $baseName);
    $$ref_conf{JSON_FILE}->{PROXY_REQUEST} = sprintf(ComConst::REQUEST_PATH . "/req_%s_%s.json", $baseName, ComFunc::getPid());
    $$ref_conf{JSON_FILE}->{PROXY_RESPONSE} = sprintf(ComConst::RESPONSE_PATH . "/res_%s_%s.json", $baseName, ComFunc::getPid());

    return $rc;
}

#=======================================================================
# FuncName : setResponseData
# Summary  : レスポンスデータ設定
# Argument : (OUT) $ref_resdata  : リクエストファイル名(reference)
#          : (IN)  $res_code     : レスポンスコード(scalar)
#          : (IN)  $res_message  : メッセージ(scalar)
# Return   : Nothing
# ----------------------------------------------------------------------
# DATE       NAME               REASON
# ---------- ------------------ ----------------------------------------
# 2015/11/26 Kiyoshi Oishi      Initial Release
#=======================================================================
sub setResponseData {
    my $ref_resdata = $_[0];
    my $res_code = $_[1];
    my $res_message = $_[2];

    $ref_resdata->{ComConst::JSON_KEY_STS} = $res_code;
    $ref_resdata->{ComConst::JSON_KEY_MSG} = $res_message;
}
