#!/bin/sh

INSTALL_DIR=/opt
if [ $# -gt 0 -a -d $1 ] ; then
	INSTALL_DIR=$1
fi
AILE_DIR=$INSTALL_DIR/aile
AILE_EXCTRL_DIR=$INSTALL_DIR/aile-exctrl
APACHE_CONF_DIR=/etc/apache2
DEFAULT_DIR=`pwd`

WWW_DIR=/var/www
WWW_SP_DIR=/var/www/sp
AILE_EXCTRL_LOG_DIR=/var/log/aile-exctrl
CGI_DIR=/usr/lib/cgi-bin
DEFAULT_BASIC_AUTH_USER=admin
DEFAULT_BASIC_AUTH_PW=11111
BASIC_AUTH_FILE=.htpasswd

### sudoers.d
if [ -e $AILE_EXCTRL_DIR/sudoers.d/aile-exctrl ]; then
	/bin/chown root:root $AILE_EXCTRL_DIR/sudoers.d/aile-exctrl
	mv $AILE_EXCTRL_DIR/sudoers.d/aile-exctrl /etc/sudoers.d/aile-exctrl
	/bin/chmod 400 /etc/sudoers.d/aile-exctrl
fi

### apache
# apacheのパッケージがインストールされている場合
if [ -e $APACHE_CONF_DIR ]; then
	# rewrite.load
	if [ -e $APACHE_CONF_DIR/mods-available/rewrite.load ]; then
		if [ ! -e $APACHE_CONF_DIR/mods-enabled/rewrite.load ]; then
			pdir=`pwd`
			cd $APACHE_CONF_DIR/mods-enabled
			ln -s ../mods-available/rewrite.load rewrite.load
			cd $pdir
		fi
	fi
	# Apacheのdefault設定を削除
	if [ -e $APACHE_CONF_DIR/sites-enabled/000-default ]; then
		rm -f $APACHE_CONF_DIR/sites-enabled/000-default
	fi
	if [ -e $APACHE_CONF_DIR/sites-available/default ]; then
		mv $APACHE_CONF_DIR/sites-available/default $APACHE_CONF_DIR/sites-available/default.org
	fi

	# インストーラにapacheの設定が含まれている
	if [ -e $AILE_EXCTRL_DIR/apache2 ]; then
		# /opt/aile/configにserverName.confがない場合
		if [ ! -e $AILE_DIR/config/serverName.conf ]; then
			# serverName.confを作成
			IP_ADDR=`/sbin/ifconfig eth0 | /bin/grep "inet addr" | /usr/bin/awk '{print $2}' | /usr/bin/awk -F: '{print $2}'`
			echo "ServerName=$IP_ADDR" >> $AILE_DIR/config/serverName.conf
			chown aile:aile $AILE_DIR/config/serverName.conf
			chmod 644 $AILE_DIR/config/serverName.conf
			# 工場出荷設定用にインストール時のファイルを残しておく
			cp -p $AILE_DIR/config/serverName.conf $AILE_DIR/serverName.conf.default
		fi
		# /opt/aile/にhttpServerName.confがない場合
		if [ ! -e $AILE_DIR/httpServerName.conf ]; then
			# httpServerName.confを作成
			IP_ADDR=`/sbin/ifconfig eth0 | /bin/grep "inet addr" | /usr/bin/awk '{print $2}' | /usr/bin/awk -F: '{print $2}'`
			echo "ServerName $IP_ADDR" >> $AILE_DIR/httpServerName.conf
			chown aile:aile $AILE_DIR/httpServerName.conf
			chmod 644 $AILE_DIR/httpServerName.conf
			# 工場出荷設定用にインストール時のファイルを残しておく
			cp -p $AILE_DIR/httpServerName.conf $AILE_DIR/httpServerName.conf.default
		fi
		# インストーラにports.confが含まれている場合
		if [ -e $AILE_EXCTRL_DIR/apache2/ports.conf ]; then
			# /opt/aile/configにports.confがない場合
			if [ ! -e $AILE_DIR/config/ports.conf ]; then
				# インストーラのports.confをコピー
				mv $AILE_EXCTRL_DIR/apache2/ports.conf $AILE_DIR/config/ports.conf
				chown aile:aile $AILE_DIR/config/ports.conf
				chmod 644 $AILE_DIR/config/ports.conf
				# 工場出荷設定用にインストール時のファイルを残しておく
                cp -p $AILE_DIR/config/ports.conf $AILE_DIR/ports.conf.default
			fi
		fi
		# インストーラにhttpPorts.confが含まれている場合
		if [ -e $AILE_EXCTRL_DIR/apache2/httpPorts.conf ]; then
			# /opt/aileにhttpPorts.confがない場合
			if [ ! -e $AILE_DIR/httpPorts.conf ]; then
				# インストーラのhttpPorts.confをコピー
				mv $AILE_EXCTRL_DIR/apache2/httpPorts.conf $AILE_DIR/httpPorts.conf
				chown aile:aile $AILE_DIR/httpPorts.conf
				chmod 644 $AILE_DIR/httpPorts.conf
				# 工場出荷設定用にインストール時のファイルを残しておく
				cp -p $AILE_DIR/httpPorts.conf $AILE_DIR/httpPorts.conf.default
			fi
		fi
		# インストーラにwebAccessUser.confが含まれている場合
		if [ -e $AILE_EXCTRL_DIR/apache2/webAccessUser.conf ]; then
			# /opt/aile/configにwebAccessUser.confがない場合
			if [ ! -e $AILE_DIR/config/webAccessUser.conf ]; then
				# インストーラのwebAccessUser.confをコピー
				mv $AILE_EXCTRL_DIR/apache2/webAccessUser.conf $AILE_DIR/config/webAccessUser.conf
				# ユーザaileが変更できるように所有者と権限を変更
				chown aile:aile $AILE_DIR/config/webAccessUser.conf
				chmod 644 $AILE_DIR/config/webAccessUser.conf
			fi
		fi
		# mime.conf
		if [ -e $AILE_EXCTRL_DIR/apache2/mods-available/mime.conf ]; then
			if [ ! -e $APACHE_CONF_DIR/mods-available/mime.conf.org ]; then
				mv $APACHE_CONF_DIR/mods-available/mime.conf $APACHE_CONF_DIR/mods-available/mime.conf.org
			fi
			mv $AILE_EXCTRL_DIR/apache2/mods-available/mime.conf $APACHE_CONF_DIR/mods-available/mime.conf
		fi
		# aileun-sites
		if [ -e $AILE_EXCTRL_DIR/apache2/aileun-sites ]; then
			if [ ! -e $AILE_DIR/aileun-sites ]; then
				# Apacheのバーチャルホスト設定
				mv $AILE_EXCTRL_DIR/apache2/aileun-sites $AILE_DIR/aileun-sites
				# 工場出荷設定用にインストール時のファイルを残しておく
				cp -p $AILE_DIR/aileun-sites $AILE_DIR/aileun-sites.default
			fi
		fi
		# _aileun-site
		if [ -e $AILE_EXCTRL_DIR/apache2/sites-available/_aileun-sites ]; then
			mv $AILE_EXCTRL_DIR/apache2/sites-available/_aileun-sites $APACHE_CONF_DIR/sites-available/_aileun-sites
			if [ ! -e $APACHE_CONF_DIR/sites-enabled/000-aileun-sites ]; then
				ln -s $AILE_DIR/aileun-sites $APACHE_CONF_DIR/sites-enabled/000-aileun-sites
			fi
		fi
		# apache2.conf
		if [ -e $AILE_EXCTRL_DIR/apache2/apache2.conf ]; then
			if [ ! -e $APACHE_CONF_DIR/apache2.conf.org ]; then
				mv $APACHE_CONF_DIR/apache2.conf $APACHE_CONF_DIR/apache2.conf.org
			fi
			mv $AILE_EXCTRL_DIR/apache2/apache2.conf $APACHE_CONF_DIR/apache2.conf
		fi
		# ports.conf
		if [ -e $APACHE_CONF_DIR/apache2.conf.org ]; then
			if [ -e $APACHE_CONF_DIR/ports.conf ]; then
				mv $APACHE_CONF_DIR/ports.conf $APACHE_CONF_DIR/ports.conf.org
			fi
		fi
	fi
fi
cd $DEFAULT_DIR;

### ailectrl
chmod 777 $AILE_EXCTRL_DIR/data
chmod 777 $AILE_EXCTRL_DIR/tmp
chmod 777 $AILE_EXCTRL_DIR/com-lib/*
chmod 777 $AILE_EXCTRL_DIR/bin/*
chmod 777 $AILE_EXCTRL_DIR/cgi-bin/*

# PC向け
cd $WWW_DIR
if [ -e index.html ]; then
	rm -f index.html
fi
# 検索エンジン/ロボット対策用ファイル
if [ -e $AILE_EXCTRL_DIR/apache2/robots.txt ]; then
	mv $AILE_EXCTRL_DIR/apache2/robots.txt $WWW_DIR/robots.txt
fi
# 認証エラー表示ページ
if [ -e $AILE_EXCTRL_DIR/apache2/error_401.html ]; then
	mv $AILE_EXCTRL_DIR/apache2/error_401.html $WWW_DIR/error_401.html
fi
# アクセスルールファイル
if [ -e $AILE_EXCTRL_DIR/apache2/.htaccess ]; then
	mv $AILE_EXCTRL_DIR/apache2/.htaccess $WWW_DIR/.htaccess
fi
# webホームディレクトリ
if [ -e $AILE_EXCTRL_DIR/html ]; then
	if [ ! -e aileun_home ]; then
		ln -s $AILE_EXCTRL_DIR/html aileun_home
	fi
fi
# CGIディレクトリ
cd $CGI_DIR
if [ -e $AILE_EXCTRL_DIR/cgi-bin ]; then
	if [ ! -e aileun_home ]; then
		ln -s $AILE_EXCTRL_DIR/cgi-bin aileun_home
	fi
fi
# Basic認証のパスワード作成
cd $AILE_EXCTRL_DIR/html
if [ ! -e .htpasswd ]; then
	# デフォルトユーザ
	/usr/bin/htpasswd -c -b $BASIC_AUTH_FILE $DEFAULT_BASIC_AUTH_USER $DEFAULT_BASIC_AUTH_PW
	chown aile:aile $BASIC_AUTH_FILE
fi
# データディレクトリ
if [ ! -e data ]; then
	ln -s ../data data
fi
# データディレクトリ
cd locales/dev
if [ ! -e translation.json ]; then
	ln -s ../en/translation.json translation.json
fi
# ログディレクトリ
cd $AILE_EXCTRL_DIR
if [ ! -e log ]; then
	if [ ! -e $AILE_EXCTRL_LOG_DIR ]; then
		mkdir -p $AILE_EXCTRL_LOG_DIR
		chmod 777 $AILE_EXCTRL_LOG_DIR
	fi
	ln -s $AILE_EXCTRL_LOG_DIR $AILE_EXCTRL_DIR/log
fi

# スマホ向け
cd $AILE_EXCTRL_DIR/html/sp
if [ ! -e data ]; then
	ln -s ../data data
fi
if [ ! -e js ]; then
	ln -s ../js js
fi
if [ ! -e css ]; then
	ln -s ../css css
fi
if [ ! -e img ]; then
	ln -s ../img img
fi
if [ ! -e fonts ]; then
	ln -s ../fonts fonts
fi
if [ ! -e locales ]; then
	ln -s ../locales locales
fi
if [ ! -e navibar.html ]; then
	ln -s ../navibar.html navibar.html
fi
if [ ! -e footer.html ]; then
	ln -s ../footer.html footer.html
fi
if [ ! -e S002-01.html ]; then
	ln -s ../S002-01.html S002-01.html
fi
if [ ! -e S003-01.html ]; then
	ln -s ../S003-01.html S003-01.html
fi
if [ ! -e S004-01.html ]; then
	ln -s ../S004-01.html S004-01.html
fi
if [ ! -e S006-01.html ]; then
	ln -s ../S006-01.html S006-01.html
fi

cd $INSTALL_DIR

rm -fr $AILE_EXCTRL_DIR/apache2
rm -fr $AILE_EXCTRL_DIR/sudoers.d
